@@ -16,16 +16,16 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "SDLEvent.h"
+#include "coriander.h"
 
 #ifdef HAVE_SDLLIB
 
-extern GtkWidget *main_window;
-extern watchthread_info_t watchthread_info;
-extern camera_t* camera;
-extern int WM_cancel_display;
-extern cursor_info_t cursor_info;
-extern xvinfo_t xvinfo;
+//extern GtkWidget *main_window;
+//extern watchthread_info_t watchthread_info;
+//extern camera_t* camera;
+//extern int WM_cancel_display;
+//extern cursor_info_t cursor_info;
+//extern xvinfo_t xvinfo;
 //extern whitebal_data_t* whitebal_data;
 
 // This should be probed automatically.
@@ -33,17 +33,6 @@ extern xvinfo_t xvinfo;
 #define MAX_DISPLAY_WIDTH  8192
 #define MAX_DISPLAY_HEIGHT 8192
 
-#define YUV2RGB(y, u, v, r, g, b)\
-  r = y + ((v*1436) >>10);\
-  g = y - ((u*352 + v*731) >> 10);\
-  b = y + ((u*1814) >> 10);\
-  r = r < 0 ? 0 : r;\
-  g = g < 0 ? 0 : g;\
-  b = b < 0 ? 0 : b;\
-  r = r > 255 ? 255 : r;\
-  g = g > 255 ? 255 : g;\
-  b = b > 255 ? 255 : b
-
 int
 SDLEventStartThread(chain_t *display_service)
 {
