@@ -16,15 +16,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include "build_frames.h"
-
-extern GtkWidget *main_window;
-extern GtkWidget *preferences_window;
-extern GtkWidget *absolute_settings_window;
-extern Prefs_t preferences;
-extern camera_t* camera;
-extern BusInfo_t* businfo;
+#include "coriander.h"
 
 void
 BuildCameraFrame(void)
@@ -163,7 +155,7 @@ BuildPrefsSaveFrame(void)
     gtk_toggle_button_set_active((GtkToggleButton*)lookup_widget(main_window, "prefs_save_noconvert"),TRUE);
   
   //filename
-  gtk_entry_set_text(GTK_ENTRY(lookup_widget(main_window, "prefs_save_filename")), camera->prefs.save_filename);
+  gtk_entry_set_text(GTK_ENTRY(gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(lookup_widget(main_window, "save_filename_entry")))), camera->prefs.save_filename);
 
   // file sequence tags
   if (camera->prefs.save_datenum==SAVE_TAG_DATE)
@@ -251,6 +243,16 @@ BuildPrefsDisplayFrame(void)
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lookup_widget(main_window,"display_redraw")), camera->prefs.display_redraw==DISPLAY_REDRAW_ON);
   gtk_spin_button_set_value((GtkSpinButton*)lookup_widget(main_window,"display_redraw_rate"), camera->prefs.display_redraw_rate);
 
+  gtk_entry_set_text(GTK_ENTRY(gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(lookup_widget(main_window, "overlay_file_entry")))), camera->prefs.overlay_filename);
+
+  BuildOverlayPatternMenu();
+  BuildOverlayTypeMenu();
+
+  gnome_color_picker_set_i8(GNOME_COLOR_PICKER(lookup_widget(main_window,"overlay_color_picker")),
+			    camera->prefs.overlay_color_r,
+			    camera->prefs.overlay_color_g,
+			    camera->prefs.overlay_color_b,0);
+  
   /*
 
   // display scaling
