@@ -16,11 +16,8 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "build_menus.h"
+#include "coriander.h"
 
-extern GtkWidget *main_window;
-extern camera_t* camera;
-extern camera_t* cameras;
 extern char* fps_label_list[NUM_FRAMERATES];
 extern char* format7_color_list[NUM_MODE_FORMAT7];
 extern char* format7_mode_list[NUM_MODE_FORMAT7];
@@ -292,12 +289,7 @@ BuildFormat7ColorMenu(void)
   gtk_option_menu_set_menu (GTK_OPTION_MENU (color_num), color_num_menu);
 
   // sets the active menu item:
-  //fprintf(stderr,"F7 mode: max: %d, default: %d\n",NUM_COLOR_FORMAT7,
-  //	  format7_info->mode[format7_info->edit_mode-MODE_FORMAT7_MIN].color_coding_id);
-  //fprintf(stderr,"current mode: %d\n", format7_info->mode[format7_info->edit_mode-MODE_FORMAT7_MIN].color_coding_id);
-  //fprintf(stderr,"history set to %d\n",index[format7_info->mode[format7_info->edit_mode-MODE_FORMAT7_MIN].color_coding_id-COLOR_FORMAT7_MIN]);
-  gtk_option_menu_set_history (GTK_OPTION_MENU (color_num),
-			       index[camera->format7_info.mode[camera->format7_info.edit_mode-MODE_FORMAT7_MIN].color_coding_id-COLOR_FORMAT7_MIN]);
+  gtk_option_menu_set_history (GTK_OPTION_MENU (color_num), index[camera->format7_info.mode[camera->format7_info.edit_mode-MODE_FORMAT7_MIN].color_coding_id-COLOR_FORMAT7_MIN]);
 
 }
 
@@ -621,35 +613,43 @@ BuildBayerPatternMenu(void)
   
   new_menu = gtk_menu_new ();
 
-  // add no BGGR option
+  // add BGGR option
   glade_menuitem = gtk_menu_item_new_with_label (_("BGGR"));
   gtk_widget_show (glade_menuitem);
   gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
   gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
 		      GTK_SIGNAL_FUNC (on_bayer_pattern_menu_activate),
-		      (int*)BAYER_PATTERN_BGGR); 
+		      (int*)COLOR_FILTER_FORMAT7_BGGR); 
   // add GRBG option
   glade_menuitem = gtk_menu_item_new_with_label (_("GRBG"));
   gtk_widget_show (glade_menuitem);
   gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
   gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
 		      GTK_SIGNAL_FUNC (on_bayer_pattern_menu_activate),
-		      (int*)BAYER_PATTERN_GRBG); 
-  // add no RGGB option
+		      (int*)COLOR_FILTER_FORMAT7_GRBG); 
+  // add RGGB option
   glade_menuitem = gtk_menu_item_new_with_label (_("RGGB"));
   gtk_widget_show (glade_menuitem);
   gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
   gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
 		      GTK_SIGNAL_FUNC (on_bayer_pattern_menu_activate),
-		      (int*)BAYER_PATTERN_RGGB); 
+		      (int*)COLOR_FILTER_FORMAT7_RGGB); 
   // add GBRG option
   glade_menuitem = gtk_menu_item_new_with_label (_("GBRG"));
   gtk_widget_show (glade_menuitem);
   gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
   gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
 		      GTK_SIGNAL_FUNC (on_bayer_pattern_menu_activate),
-		      (int*)BAYER_PATTERN_GBRG); 
-
+		      (int*)COLOR_FILTER_FORMAT7_GBRG); 
+  /*
+  // add Auto option
+  glade_menuitem = gtk_menu_item_new_with_label (_("Auto"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_bayer_pattern_menu_activate),
+		      (int*)0); 
+  */
   gtk_option_menu_set_menu (GTK_OPTION_MENU (new_option_menu), new_menu);
 
   // menu history
@@ -714,3 +714,150 @@ BuildStereoMenu(void)
   pthread_mutex_unlock(&camera->uimutex);
       
 }
+
+void
+BuildOverlayPatternMenu(void)
+{
+  GtkWidget* new_option_menu;
+  GtkWidget* new_menu;
+  GtkWidget* glade_menuitem;
+
+  // build bayer option menu:
+  gtk_widget_destroy(GTK_WIDGET(lookup_widget(main_window,"overlay_pattern_menu"))); // remove previous menu
+  
+  new_option_menu = gtk_option_menu_new ();
+  gtk_widget_ref (new_option_menu);
+  gtk_object_set_data_full (GTK_OBJECT (main_window), "overlay_pattern_menu", new_option_menu,
+			    (GtkDestroyNotify) gtk_widget_unref);
+  gtk_widget_show (new_option_menu);
+  gtk_table_attach (GTK_TABLE (lookup_widget(main_window,"table80")),
+		    new_option_menu, 0, 1, 0, 1,
+                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (new_option_menu), 1);
+  
+  new_menu = gtk_menu_new ();
+
+  // OFF
+  glade_menuitem = gtk_menu_item_new_with_label (_("OFF"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_pattern_menu_activate),
+		      (int*)OVERLAY_PATTERN_OFF);
+ 
+  // Rectangle
+  glade_menuitem = gtk_menu_item_new_with_label (_("Rectangle"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_pattern_menu_activate),
+		      (int*)OVERLAY_PATTERN_RECTANGLE);
+
+  // Small cross
+  glade_menuitem = gtk_menu_item_new_with_label (_("Small Cross"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_pattern_menu_activate),
+		      (int*)OVERLAY_PATTERN_SMALL_CROSS);
+  
+  // Large cross
+  glade_menuitem = gtk_menu_item_new_with_label (_("Large Cross"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_pattern_menu_activate),
+		      (int*)OVERLAY_PATTERN_LARGE_CROSS);
+  
+  // Golden mean (rem: golden mean is more complex and involves the golden ratio of 1.618...
+  // The "thirds" is a simplification
+  glade_menuitem = gtk_menu_item_new_with_label (_("Thirds"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_pattern_menu_activate),
+		      (int*)OVERLAY_PATTERN_GOLDEN_MEAN);
+ 
+  /*
+  // Image
+  glade_menuitem = gtk_menu_item_new_with_label (_("Custom image"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_pattern_menu_activate),
+		      (int*)OVERLAY_PATTERN_IMAGE);
+  */
+  gtk_option_menu_set_menu (GTK_OPTION_MENU (new_option_menu), new_menu);
+
+  // menu history
+  pthread_mutex_lock(&camera->uimutex);
+  gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(main_window, "overlay_pattern_menu")),camera->prefs.overlay_pattern);
+  pthread_mutex_unlock(&camera->uimutex);
+      
+}
+
+void
+BuildOverlayTypeMenu(void)
+{
+  GtkWidget* new_option_menu;
+  GtkWidget* new_menu;
+  GtkWidget* glade_menuitem;
+
+  // build bayer option menu:
+  gtk_widget_destroy(GTK_WIDGET(lookup_widget(main_window,"overlay_type_menu"))); // remove previous menu
+  
+  new_option_menu = gtk_option_menu_new ();
+  gtk_widget_ref (new_option_menu);
+  gtk_object_set_data_full (GTK_OBJECT (main_window), "overlay_type_menu", new_option_menu,
+			    (GtkDestroyNotify) gtk_widget_unref);
+  gtk_widget_show (new_option_menu);
+  gtk_table_attach (GTK_TABLE (lookup_widget(main_window,"table80")),
+		    new_option_menu, 1, 2, 0, 1,
+                    (GtkAttachOptions) (GTK_FILL),
+                    (GtkAttachOptions) (0), 0, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (new_option_menu), 1);
+  
+  new_menu = gtk_menu_new ();
+
+  // Replace
+  glade_menuitem = gtk_menu_item_new_with_label (_("Replace"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_type_menu_activate),
+		      (int*)OVERLAY_TYPE_REPLACE);
+
+  // Random
+  glade_menuitem = gtk_menu_item_new_with_label (_("Random"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_type_menu_activate),
+		      (int*)OVERLAY_TYPE_RANDOM);
+
+  // Invert
+  glade_menuitem = gtk_menu_item_new_with_label (_("Invert"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_type_menu_activate),
+		      (int*)OVERLAY_TYPE_INVERT);
+  
+  /*  
+  // Average
+  glade_menuitem = gtk_menu_item_new_with_label (_("Average"));
+  gtk_widget_show (glade_menuitem);
+  gtk_menu_append (GTK_MENU (new_menu), glade_menuitem);
+  gtk_signal_connect (GTK_OBJECT (glade_menuitem), "activate",
+		      GTK_SIGNAL_FUNC (on_overlay_type_menu_activate),
+		      (int*)OVERLAY_TYPE_AVERAGE);
+  */
+  gtk_option_menu_set_menu (GTK_OPTION_MENU (new_option_menu), new_menu);
+
+  // menu history
+  pthread_mutex_lock(&camera->uimutex);
+  gtk_option_menu_set_history(GTK_OPTION_MENU(lookup_widget(main_window, "overlay_type_menu")),camera->prefs.overlay_type);
+  pthread_mutex_unlock(&camera->uimutex);
+  
+}
