@@ -19,10 +19,6 @@
 #ifndef __BUILDWINDOWS_H__
 #define __BUILDWINDOWS_H__
 
-#include <gnome.h>
-#include "definitions.h"
-#include "build_frames.h"
-
 void
 BuildFormat7Window(void);
 
@@ -47,4 +43,4 @@ BuildHelpWindow(void);
 void
 BuildAbsoluteSettingsWindow(void);
 
-#endif
+#endif // __BUILDWINDOWS_H__
