@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
+ * Copyright (C) 2000-2004 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,23 +19,6 @@
 #ifndef __CALLBACKS_H__
 #define __CALLBACKS_H__
 
-#include <gnome.h>
-#include <libdc1394/dc1394_control.h>
-#include <pthread.h>
-#include "interface.h"
-#include "support.h"
-#include "definitions.h"
-#include "camera.h"
-#include "preferences.h"
-#include "update_frames.h" 
-#include "update_windows.h"
-#include "tools.h"
-#include "thread_display.h"
-#include "build_windows.h"
-#include "update_ranges.h"
-#include "thread_iso.h"
-#include "build_menus.h"
-
 gboolean
 on_main_window_delete_event       (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -195,32 +178,6 @@ void
 on_prefs_save_scratch_toggled          (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-void
-on_prefs_save_choose_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
-
-gboolean
-on_get_filename_dialog_delete_event    (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-gboolean
-on_get_filename_dialog_destroy_event   (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-void
-on_get_filename_dialog_destroy         (GtkObject       *object,
-                                        gpointer         user_data);
-
-void
-on_get_filename_dialog_ok_clicked      (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_get_filename_dialog_cancel_clicked  (GtkButton       *button,
-                                        gpointer         user_data);
-
 void
 on_prefs_ftp_seq_toggled               (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
@@ -427,4 +384,36 @@ void
 on_sync_control_button_toggled        (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-#endif
+void
+on_overlay_byte_order_YUYV_toggled     (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_overlay_byte_order_UYVY_toggled     (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_overlay_type_menu_activate           (GtkMenuItem     *menuitem,
+					 gpointer         user_data);
+
+void
+on_overlay_pattern_menu_activate        (GtkMenuItem     *menuitem,
+					 gpointer         user_data);
+
+void
+on_overlay_color_picker_color_set      (GnomeColorPicker *gnomecolorpicker,
+                                        guint            arg1,
+                                        guint            arg2,
+                                        guint            arg3,
+                                        guint            arg4,
+                                        gpointer         user_data);
+
+#endif // __CALLBACKS_H__
+
+void
+on_overlay_file_subentry_changed       (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_save_filename_subentry_changed      (GtkEditable     *editable,
+                                        gpointer         user_data);
