@@ -17,46 +17,15 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "conversions.h"
+#include "coriander.h"
 
+// this should disappear...
 extern void swab();
 
-// The following #define is there for the users who experience green/purple
-// images in the display. This seems to be a videocard driver problem.
-
-#define YUYV // instead of the standard UYVY
-
-// color conversion functions from Bart Nabbe.
-// corrected by Damien: bad coeficients in YUV2RGB
-#define YUV2RGB(y, u, v, r, g, b)\
-  r = y + ((v*1436) >> 10);\
-  g = y - ((u*352 + v*731) >> 10);\
-  b = y + ((u*1814) >> 10);\
-  r = r < 0 ? 0 : r;\
-  g = g < 0 ? 0 : g;\
-  b = b < 0 ? 0 : b;\
-  r = r > 255 ? 255 : r;\
-  g = g > 255 ? 255 : g;\
-  b = b > 255 ? 255 : b
-  
-
-#define RGB2YUV(r, g, b, y, u, v)\
-  y = (306*r + 601*g + 117*b)  >> 10;\
-  u = ((-172*r - 340*g + 512*b) >> 10)  + 128;\
-  v = ((512*r - 429*g - 83*b) >> 10) + 128;\
-  y = y < 0 ? 0 : y;\
-  u = u < 0 ? 0 : u;\
-  v = v < 0 ? 0 : v;\
-  y = y > 255 ? 255 : y;\
-  u = u > 255 ? 255 : u;\
-  v = v > 255 ? 255 : v
-
 #define CLIP(in, out)\
-{\
    in = in < 0 ? 0 : in;\
    in = in > 255 ? 255 : in;\
-   out=in;\
-}
+   out=in;
   
 /**********************************************************************
  *
@@ -65,95 +34,139 @@ extern void swab();
  **********************************************************************/
 
 void
-yuyv2uyvy(unsigned char *src, unsigned char *dest, unsigned long long int NumPixels)
+yuyv2uyvy(unsigned char *src, unsigned char *dest, unsigned long long int NumPixels, int byte_order)
 {
-#ifdef YUYV
-  swab(src, dest, NumPixels << 1);
-#else
-  memcpy(dest,src, NumPixels<<1);
-#endif
+  switch (byte_order) {
+  case OVERLAY_BYTE_ORDER_YUYV:
+    swab(src, dest, NumPixels << 1);
+    break;
+  case OVERLAY_BYTE_ORDER_UYVY:
+    memcpy(dest,src, NumPixels<<1);
+    break;
+  default:
+    fprintf(stderr,"Invalid overlay byte order\n");
+    break;
+  }
 }
 
 void
-uyvy2yuyv(unsigned char *src, unsigned char *dest, unsigned long long int NumPixels)
+uyvy2yuyv(unsigned char *src, unsigned char *dest, unsigned long long int NumPixels, int byte_order)
 {
-#ifdef YUYV
-  swab(src, dest, NumPixels << 1);
-#else
-  memcpy(dest,src, NumPixels<<1);
-#endif
+  switch (byte_order) {
+  case OVERLAY_BYTE_ORDER_YUYV:
+    swab(src, dest, NumPixels << 1);
+    break;
+  case OVERLAY_BYTE_ORDER_UYVY:
+    memcpy(dest,src, NumPixels<<1);
+    break;
+  default:
+    fprintf(stderr,"Invalid overlay byte order\n");
+    break;
+  }
 }
 void
-uyyvyy2uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels)
+uyyvyy2uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels, int byte_order)
 {
   register int i=NumPixels + (NumPixels >> 1)-1;
   register int j=(NumPixels << 1)-1;
   register int y0, y1, y2, y3, u, v;
 
-  while (i > 0) {
-    y3 = src[i--];
-    y2 = src[i--];
-    v  = src[i--];
-    y1 = src[i--];
-    y0 = src[i--];
-    u  = src[i--];
-#ifdef YUYV
-    dest[j--] = v;
-    dest[j--] = y3;
-    dest[j--] = u;
-    dest[j--] = y2;
-    
-    dest[j--] = v;
-    dest[j--] = y1;
-    dest[j--] = u;
-    dest[j--] = y0;
-#else // UYVY
-    dest[j--] = y3;
-    dest[j--] = v;
-    dest[j--] = y2;
-    dest[j--] = u;
-    
-    dest[j--] = y1;
-    dest[j--] = v;
-    dest[j--] = y0;
-    dest[j--] = u;
-#endif
+  switch (byte_order) {
+  case OVERLAY_BYTE_ORDER_YUYV:
+    while (i >= 0) {
+      y3 = src[i--];
+      y2 = src[i--];
+      v  = src[i--];
+      y1 = src[i--];
+      y0 = src[i--];
+      u  = src[i--];
+
+      dest[j--] = v;
+      dest[j--] = y3;
+      dest[j--] = u;
+      dest[j--] = y2;
+      
+      dest[j--] = v;
+      dest[j--] = y1;
+      dest[j--] = u;
+      dest[j--] = y0;
+    }
+    break;
+  case OVERLAY_BYTE_ORDER_UYVY:
+    while (i >= 0) {
+      y3 = src[i--];
+      y2 = src[i--];
+      v  = src[i--];
+      y1 = src[i--];
+      y0 = src[i--];
+      u  = src[i--];
+
+      dest[j--] = y3;
+      dest[j--] = v;
+      dest[j--] = y2;
+      dest[j--] = u;
+      
+      dest[j--] = y1;
+      dest[j--] = v;
+      dest[j--] = y0;
+      dest[j--] = u;
+    }
+    break;
+  default:
+    fprintf(stderr,"Invalid overlay byte order\n");
+    break;
   }
+
 }
 
 void
-uyv2uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels)
+uyv2uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels, int byte_order)
 {
   register int i = NumPixels + (NumPixels << 1)-1;
   register int j = (NumPixels << 1)-1;
   register int y0, y1, u0, u1, v0, v1;
 
-  while (i > 0) {
-    v1 = src[i--];
-    y1 = src[i--];
-    u1 = src[i--];
-    v0 = src[i--];
-    y0 = src[i--];
-    u0 = src[i--];
-    
-#ifdef YUYV
-    dest[j--] = (v0+v1) >> 1;
-    dest[j--] = y1;
-    dest[j--] = (u0+u1) >> 1;
-    dest[j--] = y0;
-#else // UYVY
-    dest[j--] = y1;
-    dest[j--] = (v0+v1) >> 1;
-    dest[j--] = y0;
-    dest[j--] = (u0+u1) >> 1;
-#endif
+  switch (byte_order) {
+  case OVERLAY_BYTE_ORDER_YUYV:
+    while (i >= 0) {
+      v1 = src[i--];
+      y1 = src[i--];
+      u1 = src[i--];
+      v0 = src[i--];
+      y0 = src[i--];
+      u0 = src[i--];
+
+      dest[j--] = (v0+v1) >> 1;
+      dest[j--] = y1;
+      dest[j--] = (u0+u1) >> 1;
+      dest[j--] = y0;
     }
+    break;
+  case OVERLAY_BYTE_ORDER_UYVY:
+    while (i >= 0) {
+      v1 = src[i--];
+      y1 = src[i--];
+      u1 = src[i--];
+      v0 = src[i--];
+      y0 = src[i--];
+      u0 = src[i--];
+
+      dest[j--] = y1;
+      dest[j--] = (v0+v1) >> 1;
+      dest[j--] = y0;
+      dest[j--] = (u0+u1) >> 1;
+    }
+    break;
+  default:
+    fprintf(stderr,"Invalid overlay byte order\n");
+    break;
+  }
 }
 
 void
 y2uyvy (unsigned char *src, unsigned char *dest, 
 	unsigned long src_width, unsigned long src_height,
-	unsigned long dest_pitch)
+	unsigned long dest_pitch, int byte_order)
 {
   if ((src_width*2) == dest_pitch) {
     // do it the quick way
@@ -161,73 +174,107 @@ y2uyvy (unsigned char *src, unsigned char *dest,
     register int j = (src_width*src_height << 1) - 1;
     register int y0, y1;
     
-    while (i > 0) {
-      y1 = src[i--];
-      y0 = src[i--];
-#ifdef YUYV
-      dest[j--] = 128;
-      dest[j--] = y1;
-      dest[j--] = 128;
-      dest[j--] = y0;
-#else // UYVY
-      dest[j--] = y1;
-      dest[j--] = 128;
-      dest[j--] = y0;
-      dest[j--] = 128;
-#endif
+    switch (byte_order) {
+    case OVERLAY_BYTE_ORDER_YUYV:
+      while (i >= 0) {
+	y1 = src[i--];
+	y0 = src[i--];
+	dest[j--] = 128;
+	dest[j--] = y1;
+	dest[j--] = 128;
+	dest[j--] = y0;
+      }
+      break;
+    case OVERLAY_BYTE_ORDER_UYVY:
+      while (i >= 0) {
+	y1 = src[i--];
+	y0 = src[i--];
+	dest[j--] = y1;
+	dest[j--] = 128;
+	dest[j--] = y0;
+	dest[j--] = 128;
+      }
+      break;
+    default:
+      fprintf(stderr,"Invalid overlay byte order\n");
+      break;
     }
   } else { // src_width*2 != dest_pitch
     register int x, y;
 
     //assert ((dest_pitch - 2*src_width)==1);
 
-    y=src_height;
-    while (y--) {
-      x=src_width;
-      while (x--) {
-#ifdef YUYV
-	*dest++ = *src++;
+    switch (byte_order) {
+    case OVERLAY_BYTE_ORDER_YUYV:
+      y=src_height;
+      while (y--) {
+	x=src_width;
+	while (x--) {
+	  *dest++ = *src++;
+	  *dest++ = 128;
+	}
+	// padding required, duplicate last column
+	*dest++ = *(src-1);
 	*dest++ = 128;
-#else
-	*dest++ = 128;
-	*dest++ = *src++;
-#endif
       }
-      // padding required, duplicate last collumn
-#ifdef YUYV
-      *dest++ = *(src-1);
-      *dest++ = 128;
-#else
-      *dest++ = 128;
-      *dest++ = *(src-1);
-#endif
+      break;
+    case OVERLAY_BYTE_ORDER_UYVY:
+      y=src_height;
+      while (y--) {
+	x=src_width;
+	while (x--) {
+	  *dest++ = 128;
+	  *dest++ = *src++;
+	}
+	// padding required, duplicate last column
+	*dest++ = 128;
+	*dest++ = *(src-1);
+      }
+      break;
+    default:
+      fprintf(stderr,"Invalid overlay byte order\n");
+      break;
     }
   }
 }
 
 void
-y162uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels, int bits)
+y162uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels, int bits, int byte_order)
 {
   register int i = (NumPixels << 1)-1;
   register int j = (NumPixels << 1)-1;
   register int y0, y1;
-  while (i > 0) {
-    y1 = src[i--];
-    y1 = (y1 + (((int)src[i--])<<8))>>(bits-8);
-    y0 = src[i--];
-    y0 = (y0 + (((int)src[i--])<<8))>>(bits-8);
-#ifdef YUYV
-    dest[j--] = 128;
-    dest[j--] = y1;
-    dest[j--] = 128;
-    dest[j--] = y0;
-#else // UYVY
-    dest[j--] = y1;
-    dest[j--] = 128;
-    dest[j--] = y0;
-    dest[j--] = 128;
-#endif
+
+  switch (byte_order) {
+  case OVERLAY_BYTE_ORDER_YUYV:
+    while (i >= 0) {
+      y1 = src[i--];
+      y1 = (y1 + (((int)src[i--])<<8))>>(bits-8);
+      y0 = src[i--];
+      y0 = (y0 + (((int)src[i--])<<8))>>(bits-8);
+      dest[j--] = 128;
+      dest[j--] = y1;
+      dest[j--] = 128;
+      dest[j--] = y0;
+    }
+    break;
+  case OVERLAY_BYTE_ORDER_UYVY:
+    while (i >= 0) {
+      y1 = src[i--];
+      y1 = (y1 + (((int)src[i--])<<8))>>(bits-8);
+      y0 = src[i--];
+      y0 = (y0 + (((int)src[i--])<<8))>>(bits-8);
+      dest[j--] = y1;
+      dest[j--] = 128;
+      dest[j--] = y0;
+      dest[j--] = 128;
+    }
+    break;
+  default:
+    fprintf(stderr,"Invalid overlay byte order\n");
+    break;
   }
+
 }
 
 void
@@ -237,78 +284,115 @@ y162y (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels
   register int j = NumPixels-1;
   register int y;
 
-  while (i > 0) {
+  while (i >= 0) {
     y = src[i--];
     dest[j--] = (y + (src[i--]<<8))>>(bits-8);
   }
 }
 
 void
-rgb2uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels)
+rgb2uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels, int byte_order)
 {
   register int i = NumPixels + ( NumPixels << 1 )-1;
   register int j = (NumPixels << 1)-1;
   register int y0, y1, u0, u1, v0, v1 ;
   register int r, g, b;
 
-  while (i > 0) {
-    b = (unsigned char) src[i--];
-    g = (unsigned char) src[i--];
-    r = (unsigned char) src[i--];
-    RGB2YUV (r, g, b, y0, u0 , v0);
-    b = (unsigned char) src[i--];
-    g = (unsigned char) src[i--];
-    r = (unsigned char) src[i--];
-    RGB2YUV (r, g, b, y1, u1 , v1);
-#ifdef YUYV
-    dest[j--] = (v0+v1) >> 1;
-    dest[j--] = y0;
-    dest[j--] = (u0+u1) >> 1;
-    dest[j--] = y1;
-#else // UYVY
-    dest[j--] = y0;
-    dest[j--] = (v0+v1) >> 1;
-    dest[j--] = y1;
-    dest[j--] = (u0+u1) >> 1;
-#endif
+  switch (byte_order) {
+  case OVERLAY_BYTE_ORDER_YUYV:
+    while (i >= 0) {
+      b = (unsigned char) src[i--];
+      g = (unsigned char) src[i--];
+      r = (unsigned char) src[i--];
+      RGB2YUV (r, g, b, y0, u0 , v0);
+      b = (unsigned char) src[i--];
+      g = (unsigned char) src[i--];
+      r = (unsigned char) src[i--];
+      RGB2YUV (r, g, b, y1, u1 , v1);
+      dest[j--] = (v0+v1) >> 1;
+      dest[j--] = y0;
+      dest[j--] = (u0+u1) >> 1;
+      dest[j--] = y1;
+    }
+    break;
+  case OVERLAY_BYTE_ORDER_UYVY:
+    while (i >= 0) {
+      b = (unsigned char) src[i--];
+      g = (unsigned char) src[i--];
+      r = (unsigned char) src[i--];
+      RGB2YUV (r, g, b, y0, u0 , v0);
+      b = (unsigned char) src[i--];
+      g = (unsigned char) src[i--];
+      r = (unsigned char) src[i--];
+      RGB2YUV (r, g, b, y1, u1 , v1);
+      dest[j--] = y0;
+      dest[j--] = (v0+v1) >> 1;
+      dest[j--] = y1;
+      dest[j--] = (u0+u1) >> 1;
+    }
+    break;
+  default:
+    fprintf(stderr,"Invalid overlay byte order\n");
+    break;
   }
 }
 
 void
-rgb482uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels)
+rgb482uyvy (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels, int byte_order)
 {
   register int i = ( (NumPixels + ( NumPixels << 1 )) << 1 ) -1;
   register int j = (NumPixels << 1)-1;
   register int y0, y1, u0, u1, v0, v1 ;
   register int r, g, b;
 
-  while (i > 0) {
-    i--;
-    b = (unsigned char) src[i--];
-    i--;
-    g = (unsigned char) src[i--];
-    i--;
-    r = (unsigned char) src[i--];
-    i--;
-    RGB2YUV (r, g, b, y0, u0 , v0);
-    b = (unsigned char) src[i--];
-    i--;
-    g = (unsigned char) src[i--];
-    i--;
-    r = (unsigned char) src[i--];
-    RGB2YUV (r, g, b, y1, u1 , v1);
-    
-#ifdef YUYV
-    dest[j--] = (v0+v1) >> 1;
-    dest[j--] = y0;
-    dest[j--] = (u0+u1) >> 1;
-    dest[j--] = y1;
-#else // UYVY
-    dest[j--] = y0;
-    dest[j--] = (v0+v1) >> 1;
-    dest[j--] = y1;
-    dest[j--] = (u0+u1) >> 1;
-#endif
+  switch (byte_order) {
+  case OVERLAY_BYTE_ORDER_YUYV:
+    while (i >= 0) {
+      i--;
+      b = (unsigned char) src[i--];
+      i--;
+      g = (unsigned char) src[i--];
+      i--;
+      r = (unsigned char) src[i--];
+      i--;
+      RGB2YUV (r, g, b, y0, u0 , v0);
+      b = (unsigned char) src[i--];
+      i--;
+      g = (unsigned char) src[i--];
+      i--;
+      r = (unsigned char) src[i--];
+      RGB2YUV (r, g, b, y1, u1 , v1);
+      dest[j--] = (v0+v1) >> 1;
+      dest[j--] = y0;
+      dest[j--] = (u0+u1) >> 1;
+      dest[j--] = y1;
+    } 
+    break;
+  case OVERLAY_BYTE_ORDER_UYVY:
+    while (i >= 0) {
+      i--;
+      b = (unsigned char) src[i--];
+      i--;
+      g = (unsigned char) src[i--];
+      i--;
+      r = (unsigned char) src[i--];
+      i--;
+      RGB2YUV (r, g, b, y0, u0 , v0);
+      b = (unsigned char) src[i--];
+      i--;
+      g = (unsigned char) src[i--];
+      i--;
+      r = (unsigned char) src[i--];
+      RGB2YUV (r, g, b, y1, u1 , v1);
+      dest[j--] = y0;
+      dest[j--] = (v0+v1) >> 1;
+      dest[j--] = y1;
+      dest[j--] = (u0+u1) >> 1;
+    }
+    break;
+  default:
+    fprintf(stderr,"Invalid overlay byte order\n");
+    break;
   }
 }
 
@@ -324,7 +408,7 @@ rgb482rgb (unsigned char *src, unsigned char *dest, unsigned long long int NumPi
   register int i = ((NumPixels + ( NumPixels << 1 )) << 1)-1;
   register int j = NumPixels + ( NumPixels << 1 ) -1;
 
-  while (i > 0) {
+  while (i >= 0) {
     i--;
     dest[j--]=src[i--];
     i--;
@@ -343,7 +427,7 @@ uyv2rgb (unsigned char *src, unsigned char *dest, unsigned long long int NumPixe
   register int y, u, v;
   register int r, g, b;
 
-  while (i > 0) {
+  while (i >= 0) {
     v = (unsigned char) src[i--] - 128;
     y = (unsigned char) src[i--];
     u = (unsigned char) src[i--] - 128;
@@ -362,7 +446,7 @@ uyvy2rgb (unsigned char *src, unsigned char *dest, unsigned long long int NumPix
   register int y0, y1, u, v;
   register int r, g, b;
 
-  while (i > 0) {
+  while (i >= 0) {
     y1 = (unsigned char) src[i--];
     v  = (unsigned char) src[i--] - 128;
     y0 = (unsigned char) src[i--];
@@ -387,7 +471,7 @@ uyyvyy2rgb (unsigned char *src, unsigned char *dest, unsigned long long int NumP
   register int y0, y1, y2, y3, u, v;
   register int r, g, b;
   
-  while (i > 0) {
+  while (i >= 0) {
     y3 = (unsigned char) src[i--];
     y2 = (unsigned char) src[i--];
     v  = (unsigned char) src[i--] - 128;
@@ -420,7 +504,7 @@ y2rgb (unsigned char *src, unsigned char *dest, unsigned long long int NumPixels
   register int j = NumPixels + ( NumPixels << 1 )-1;
   register int y;
 
-  while (i > 0) {
+  while (i >= 0) {
     y = (unsigned char) src[i--];
     dest[j--] = y;
     dest[j--] = y;
@@ -454,33 +538,34 @@ y162rgb (unsigned char *src, unsigned char *dest, unsigned long long int NumPixe
  *****************************************************************/
 
 void
-BayerNearestNeighbor(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_pattern_t type)
+BayerNearestNeighbor(unsigned char *src, unsigned char *dest, int sx, int sy, int type)
 {
-  unsigned char *outR, *outG, *outB;
+  unsigned char *outR=NULL, *outG=NULL, *outB=NULL;
   register int i,j;
 
   // sx and sy should be even
   switch (type) {
-  case BAYER_PATTERN_GRBG:
-  case BAYER_PATTERN_BGGR:
+  case COLOR_FILTER_FORMAT7_GRBG:
+  case COLOR_FILTER_FORMAT7_BGGR:
     outR=&dest[0];
     outG=&dest[1];
     outB=&dest[2];
     break;
-  case BAYER_PATTERN_GBRG:
-  case BAYER_PATTERN_RGGB:
+  case COLOR_FILTER_FORMAT7_GBRG:
+  case COLOR_FILTER_FORMAT7_RGGB:
     outR=&dest[2];
     outG=&dest[1];
     outB=&dest[0];
     break;
   default:
-    outR=NULL;outG=NULL;outB=NULL;
+    fprintf(stderr,"Bad Bayer pattern ID: %d\n",type);
+    return;
     break;
   }
   
   switch (type) {
-  case BAYER_PATTERN_GRBG: //-------------------------------------------
-  case BAYER_PATTERN_GBRG:
+  case COLOR_FILTER_FORMAT7_GRBG: //-------------------------------------------
+  case COLOR_FILTER_FORMAT7_GBRG:
     // copy original RGB data to output images
     for (i=0;i<sy;i+=2) {
       for (j=0;j<sx;j+=2) {
@@ -522,8 +607,8 @@ BayerNearestNeighbor(unsigned char *src, unsigned char *dest, int sx, int sy, ba
       outG[((sy-1)*sx+j)*3]=outG[((sy-2)*sx+j)*3];
     
     break;
-  case BAYER_PATTERN_BGGR: //-------------------------------------------
-  case BAYER_PATTERN_RGGB:
+  case COLOR_FILTER_FORMAT7_BGGR: //-------------------------------------------
+  case COLOR_FILTER_FORMAT7_RGGB:
     // copy original data
     for (i=0;i<sy;i+=2) {
       for (j=0;j<sx;j+=2) {
@@ -567,41 +652,44 @@ BayerNearestNeighbor(unsigned char *src, unsigned char *dest, int sx, int sy, ba
     break;
     
   default:  //-------------------------------------------
+    fprintf(stderr,"Bad Bayer pattern ID: %d\n",type);
+    return;
     break;
   }
 }
 
 
 void
-BayerEdgeSense(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_pattern_t type)
+BayerEdgeSense(unsigned char *src, unsigned char *dest, int sx, int sy, int type)
 {
-  unsigned char *outR, *outG, *outB;
+  unsigned char *outR=NULL, *outG=NULL, *outB=NULL;
   register int i,j;
   int dh, dv;
   int tmp;
 
   // sx and sy should be even
   switch (type) {
-  case BAYER_PATTERN_GRBG:
-  case BAYER_PATTERN_BGGR:
+  case COLOR_FILTER_FORMAT7_GRBG:
+  case COLOR_FILTER_FORMAT7_BGGR:
     outR=&dest[0];
     outG=&dest[1];
     outB=&dest[2];
     break;
-  case BAYER_PATTERN_GBRG:
-  case BAYER_PATTERN_RGGB:
+  case COLOR_FILTER_FORMAT7_GBRG:
+  case COLOR_FILTER_FORMAT7_RGGB:
     outR=&dest[2];
     outG=&dest[1];
     outB=&dest[0];
     break;
   default:
-    outR=NULL;outG=NULL;outB=NULL;
+    fprintf(stderr,"Bad Bayer pattern ID: %d\n",type);
+    return;
     break;
   }
 
   switch (type) {
-  case BAYER_PATTERN_GRBG://---------------------------------------------------------
-  case BAYER_PATTERN_GBRG:
+  case COLOR_FILTER_FORMAT7_GRBG://---------------------------------------------------------
+  case COLOR_FILTER_FORMAT7_GBRG:
     // copy original RGB data to output images
     for (i=0;i<sy;i+=2) {
       for (j=0;j<sx;j+=2) {
@@ -690,8 +778,8 @@ BayerEdgeSense(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_pa
     }
       break;
 
-  case BAYER_PATTERN_BGGR: //---------------------------------------------------------
-  case BAYER_PATTERN_RGGB:
+  case COLOR_FILTER_FORMAT7_BGGR: //---------------------------------------------------------
+  case COLOR_FILTER_FORMAT7_RGGB:
     // copy original RGB data to output images
     for (i=0;i<sy;i+=2) {
       for (j=0;j<sx;j+=2) {
@@ -779,15 +867,45 @@ BayerEdgeSense(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_pa
     }
     break;
   default: //---------------------------------------------------------
-    fprintf(stderr,"Bad bayer pattern ID\n");
+    fprintf(stderr,"Bad Bayer pattern ID: %d\n",type);
+    return;
     break;
   }
+  
+  ClearBorders(dest, sx, sy, 3);
+
 }
 
 void
-BayerDownsample(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_pattern_t type)
+ClearBorders(unsigned char* dest, int sx, int sy, int w) 
 {
-  unsigned char *outR, *outG, *outB;
+  int i,j;
+
+  // black edges:
+  i=3*sx*w-1;
+  j=3*sx*(sy-1)-1;
+  while (i>=0) {
+    dest[i--]=0;
+    dest[j--]=0;
+  }
+  
+  i=sx*(sy-1)*3-1+w*3;
+  while (i>sx) {
+    j=6*w;
+    while (j>0) {
+      dest[i--]=0;
+      j--;
+    }
+    i-=(sx-2*w)*3;
+  }
+  
+}
+
+
+void
+BayerDownsample(unsigned char *src, unsigned char *dest, int sx, int sy, int type)
+{
+  unsigned char *outR=NULL, *outG=NULL, *outB=NULL;
   register int i,j;
   int tmp;
 
@@ -795,26 +913,27 @@ BayerDownsample(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_p
   sy*=2;
 
   switch (type) {
-  case BAYER_PATTERN_GRBG:
-  case BAYER_PATTERN_BGGR:
+  case COLOR_FILTER_FORMAT7_GRBG:
+  case COLOR_FILTER_FORMAT7_BGGR:
     outR=&dest[0];
     outG=&dest[1];
     outB=&dest[2];
     break;
-  case BAYER_PATTERN_GBRG:
-  case BAYER_PATTERN_RGGB:
+  case COLOR_FILTER_FORMAT7_GBRG:
+  case COLOR_FILTER_FORMAT7_RGGB:
     outR=&dest[2];
     outG=&dest[1];
     outB=&dest[0];
     break;
   default:
-    outR=NULL;outG=NULL;outB=NULL;
+    fprintf(stderr,"Bad Bayer pattern ID: %d\n",type);
+    return;
     break;
   }
   
   switch (type) {
-  case BAYER_PATTERN_GRBG://---------------------------------------------------------
-  case BAYER_PATTERN_GBRG:
+  case COLOR_FILTER_FORMAT7_GRBG://---------------------------------------------------------
+  case COLOR_FILTER_FORMAT7_GBRG:
     for (i=0;i<sy;i+=2) {
       for (j=0;j<sx;j+=2) {
 	tmp=((src[i*sx+j]+src[(i+1)*sx+(j+1)])>>1);
@@ -826,8 +945,8 @@ BayerDownsample(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_p
       }
     }
     break;
-  case BAYER_PATTERN_BGGR://---------------------------------------------------------
-  case BAYER_PATTERN_RGGB:
+  case COLOR_FILTER_FORMAT7_BGGR://---------------------------------------------------------
+  case COLOR_FILTER_FORMAT7_RGGB:
     for (i=0;i<sy;i+=2) {
       for (j=0;j<sx;j+=2) {
 	tmp=((src[(i+1)*sx+j]+src[i*sx+(j+1)])>>1);
@@ -840,41 +959,43 @@ BayerDownsample(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_p
     }
     break;
   default: //---------------------------------------------------------
-    fprintf(stderr,"Bad bayer pattern ID\n");
+    fprintf(stderr,"Bad Bayer pattern ID: %d\n",type);
+    return;
     break;
   }
   
 }
 
 void
-BayerSimple(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_pattern_t type)
+BayerSimple(unsigned char *src, unsigned char *dest, int sx, int sy, int type)
 {
-  unsigned char *outR, *outG, *outB;
+  unsigned char *outR=NULL, *outG=NULL, *outB=NULL;
   register int i,j;
   int tmp, base;
-
+  
   switch (type) {
-  case BAYER_PATTERN_GRBG:
-  case BAYER_PATTERN_BGGR:
+  case COLOR_FILTER_FORMAT7_GRBG:
+  case COLOR_FILTER_FORMAT7_BGGR:
     outR=&dest[0];
     outG=&dest[1];
     outB=&dest[2];
     break;
-  case BAYER_PATTERN_GBRG:
-  case BAYER_PATTERN_RGGB:
+  case COLOR_FILTER_FORMAT7_GBRG:
+  case COLOR_FILTER_FORMAT7_RGGB:
     outR=&dest[2];
     outG=&dest[1];
     outB=&dest[0];
     break;
   default:
-    outR=NULL;outG=NULL;outB=NULL;
+    fprintf(stderr,"Bad Bayer pattern ID: %d\n",type);
+    return;
     break;
   }
   
   switch (type) {
-  case BAYER_PATTERN_GRBG://---------------------------------------------------------
-  case BAYER_PATTERN_GBRG:
-    for (i=0;i<sy-1;i+=1) {
+  case COLOR_FILTER_FORMAT7_GRBG://---------------------------------------------------------
+  case COLOR_FILTER_FORMAT7_GBRG:
+    for (i=0;i<sy-1;i+=2) {
       for (j=0;j<sx-1;j+=2) {
 	base=i*sx+j;
 	tmp=((src[base]+src[base+sx+1])>>1);
@@ -883,15 +1004,20 @@ BayerSimple(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_patte
 	CLIP(tmp,outR[base*3]);
 	tmp=src[base+sx];
 	CLIP(tmp,outB[base*3]);
-
-	tmp=((src[base+2]+src[base+sx+1])>>1);
-	CLIP(tmp,outG[(base+1)*3]);
-	tmp=src[base+1];
-	CLIP(tmp,outR[(base+1)*3]);
-	tmp=src[base+2+sx];
-	CLIP(tmp,outB[(base+1)*3]);
       }
-      i+=1;
+    }
+    for (i=0;i<sy-1;i+=2) {
+      for (j=1;j<sx-1;j+=2) {
+	base=i*sx+j;
+	tmp=((src[base+1]+src[base+sx])>>1);
+	CLIP(tmp,outG[(base)*3]);
+	tmp=src[base];
+	CLIP(tmp,outR[(base)*3]);
+	tmp=src[base+1+sx];
+	CLIP(tmp,outB[(base)*3]);
+      }
+    }
+    for (i=1;i<sy-1;i+=2) {
       for (j=0;j<sx-1;j+=2) {
 	base=i*sx+j;
 	tmp=((src[base+sx]+src[base+1])>>1);
@@ -900,19 +1026,23 @@ BayerSimple(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_patte
 	CLIP(tmp,outR[base*3]);
 	tmp=src[base];
 	CLIP(tmp,outB[base*3]);
-
-	tmp=((src[base+1]+src[base+2+sx])>>1);
-	CLIP(tmp,outG[(base+1)*3]);
-	tmp=src[base+sx+1];
-	CLIP(tmp,outR[(base+1)*3]);
-	tmp=src[base+2];
-	CLIP(tmp,outB[(base+1)*3]);
+      }
+    }
+    for (i=1;i<sy-1;i+=2) {
+      for (j=1;j<sx-1;j+=2) {
+	base=i*sx+j;
+	tmp=((src[base]+src[base+1+sx])>>1);
+	CLIP(tmp,outG[(base)*3]);
+	tmp=src[base+sx];
+	CLIP(tmp,outR[(base)*3]);
+	tmp=src[base+1];
+	CLIP(tmp,outB[(base)*3]);
       }
     }
     break;
-  case BAYER_PATTERN_BGGR://---------------------------------------------------------
-  case BAYER_PATTERN_RGGB:
-    for (i=0;i<sy-1;i+=1) {
+  case COLOR_FILTER_FORMAT7_BGGR://---------------------------------------------------------
+  case COLOR_FILTER_FORMAT7_RGGB:
+    for (i=0;i<sy-1;i+=2) {
       for (j=0;j<sx-1;j+=2) {
 	base=i*sx+j;
 	tmp=((src[base+sx]+src[base+1])>>1);
@@ -921,37 +1051,59 @@ BayerSimple(unsigned char *src, unsigned char *dest, int sx, int sy, bayer_patte
 	CLIP(tmp,outR[base*3]);
 	tmp=src[base];
 	CLIP(tmp,outB[base*3]);
-
-	tmp=((src[base+1]+src[base+2+sx])>>1);
-	CLIP(tmp,outG[(base+1)*3]);
-	tmp=src[base+sx+1];
-	CLIP(tmp,outR[(base+1)*3]);
-	tmp=src[base+2];
-	CLIP(tmp,outB[(base+1)*3]);
       }
-      i+=1;
+    }
+    for (i=1;i<sy-1;i+=2) {
       for (j=0;j<sx-1;j+=2) {
+	base=i*sx+j;
+	tmp=((src[base]+src[base+1+sx])>>1);
+	CLIP(tmp,outG[(base)*3]);
+	tmp=src[base+1];
+	CLIP(tmp,outR[(base)*3]);
+	tmp=src[base+sx];
+	CLIP(tmp,outB[(base)*3]);
+      }
+    }
+    for (i=0;i<sy-1;i+=2) {
+      for (j=1;j<sx-1;j+=2) {
 	base=i*sx+j;
 	tmp=((src[base]+src[base+sx+1])>>1);
 	CLIP(tmp,outG[base*3]);
-	tmp=src[base+1];
-	CLIP(tmp,outR[base*3]);
 	tmp=src[base+sx];
-	CLIP(tmp,outB[base*3]);
-
-	tmp=((src[base+2]+src[base+sx+1])>>1);
-	CLIP(tmp,outG[(base+1)*3]);
+	CLIP(tmp,outR[base*3]);
 	tmp=src[base+1];
-	CLIP(tmp,outR[(base+1)*3]);
-	tmp=src[base+2+sx];
-	CLIP(tmp,outB[(base+1)*3]);
+	CLIP(tmp,outB[base*3]);
+      }
+    }
+    for (i=1;i<sy-1;i+=2) {
+      for (j=1;j<sx-1;j+=2) {
+	base=i*sx+j;
+	tmp=((src[base+1]+src[base+sx])>>1);
+	CLIP(tmp,outG[(base)*3]);
+	tmp=src[base];
+	CLIP(tmp,outR[(base)*3]);
+	tmp=src[base+1+sx];
+	CLIP(tmp,outB[(base)*3]);
       }
     }
     break;
   default: //---------------------------------------------------------
-    fprintf(stderr,"Bad bayer pattern ID\n");
+    fprintf(stderr,"Bad Bayer pattern ID: %d\n",type);
+    return;
     break;
   }
+ 
+  // add black border
+  for (i=sx*(sy-1)*3;i<sx*sy*3;i++) {
+    dest[i]=0;
+  }
+  for (i=(sx-1)*3;i<sx*sy*3;i+=(sx-1)*3) {
+    dest[i++]=0;
+    dest[i++]=0;
+    dest[i++]=0;
+  }
+
+
 }
 
 // change a 16bit stereo image (8bit/channel) into two 8bit images on top
@@ -963,7 +1115,7 @@ StereoDecode(unsigned char *src, unsigned char *dest, unsigned long long int Num
   register int j = (NumPixels>>1)-1;
   register int k = NumPixels-1;
 
-  while (i > 0) {
+  while (i >= 0) {
     dest[k--] = src[i--];
     dest[j--] = src[i--];
   }
