@@ -19,12 +19,6 @@
 #ifndef __DEFINITIONS_H__
 #define __DEFINITIONS_H__
 
-#include <libdc1394/dc1394_control.h>
-#include <sys/times.h>
-#include <pthread.h>
-#include "raw1394support.h"
-#include "conversions.h"
-
 #define  BU                  1000     // definitions for distinguishing the BU and RV
 #define  RV                  2000     // scales of the FEATURE_WHITE_BALANCE feature
 #define  NO                 FALSE
@@ -82,6 +76,13 @@ typedef struct _CamPrefs
 
   char* name;
 
+  char *overlay_filename;
+  int overlay_type;
+  int overlay_color_r;
+  int overlay_color_g;
+  int overlay_color_b;
+  int overlay_pattern;
+
   // internal data:
   int receive_method2index[2];
 
@@ -93,6 +94,8 @@ typedef struct _Prefs
   int auto_update;
   float auto_update_frequency;
   int sync_control;
+  
+  int overlay_byte_order;
 
   struct _CamPrefs camprefs;
 
@@ -196,7 +199,7 @@ typedef struct _Buffer_T
   int bpp; // this bpp is used for 16bit camera that only have e.g. 12 bits.
   unsigned long long int image_bytes;
   bayer_decoding_t bayer;
-  bayer_pattern_t bayer_pattern;
+  int bayer_pattern;
   stereo_decoding_t stereo_decoding;
   int format7_color_mode;
 
@@ -316,5 +319,5 @@ typedef struct _CtxtInfo
 } CtxtInfo_t;
 
 
-#endif
+#endif // __DEFINITIONS_H__
 
