@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* $Id: raw1394support.h,v 1.3 2002/01/02 15:19:19 ddouxchamps Exp $
+/* $Id: raw1394support.h,v 1.5 2004/11/24 05:39:18 ddouxchamps Exp $
  *
  * raw1394.h - Linux IEEE-1394 Subsystem RAW 1394 support library
  * for some compatibility with older library
@@ -25,9 +25,6 @@
 #ifndef __RAW1394SUPPORT_H__
 #define __RAW1394SUPPORT_H__
 
-#include <libraw1394/raw1394.h>
-#include <libraw1394/csr.h>
-
 #define SELFID_PORT_CHILD        0x3
 #define SELFID_PORT_PARENT       0x2
 #define SELFID_PORT_NCONN        0x1
@@ -78,4 +75,4 @@ typedef struct RAW1394topologyMap_t {
     SelfIdPacket_t selfIdPacket[(0x400 - 4)];
 } RAW1394topologyMap;
 
-#endif
+#endif // __RAW1394SUPPORT_H__
