@@ -16,10 +16,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "thread_base.h" 
-
-extern camera_t* camera;
-extern camera_t* cameras;
+#include "coriander.h"
 
 chain_t*
 GetService(camera_t* cam, service_t service)
@@ -259,7 +256,7 @@ InitBuffer(buffer_t *buffer)
   buffer->mode=-1;
   buffer->bayer=-1;
   buffer->bpp=-1;
-  buffer->bayer_pattern=-1;
+  buffer->bayer_pattern=-1;//COLOR_FILTER_FORMAT7_BGGR
   buffer->stereo_decoding=-1;
   buffer->format=-1;
   buffer->format7_color_mode=-1;
