@@ -16,16 +16,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "thread_display.h"
-
-extern GtkWidget *main_window;
-extern CtxtInfo_t ctxt;
-extern camera_t* camera;
-extern xvinfo_t xvinfo;
-
-#ifdef HAVE_SDLLIB
-extern watchthread_info_t watchthread_info;
-#endif
+#include "coriander.h"
 
 gint
 DisplayStartThread(camera_t* cam)
@@ -128,15 +119,19 @@ DisplayThread(void* arg)
 	  if (skip_counter>=(info->period-1)) {
 	    skip_counter=0;
 #ifdef HAVE_SDLLIB
-	    if (SDL_LockYUVOverlay(info->sdloverlay) == 0) {
-	      convert_to_yuv_for_SDL(display_service->current_buffer, info->sdloverlay);
-	      
-	      SDLDisplayArea(display_service);
-	      
-	      SDL_UnlockYUVOverlay(info->sdloverlay);
-	      SDL_DisplayYUVOverlay(info->sdloverlay, &info->sdlvideorect);
-	      
-	      info->redraw_prev_time=times(&info->redraw_tms_buf);
+	    if (info->sdloverlay!=NULL) {
+	      if (SDL_LockYUVOverlay(info->sdloverlay) == 0) {
+		convert_to_yuv_for_SDL(display_service->current_buffer, info->sdloverlay, preferences.overlay_byte_order);
+		
+		// informative overlays
+		SDLDisplayArea(display_service);
+		SDLDisplayPattern(display_service);
+		
+		SDL_UnlockYUVOverlay(info->sdloverlay);
+		SDL_DisplayYUVOverlay(info->sdloverlay, &info->sdlvideorect);
+		
+		info->redraw_prev_time=times(&info->redraw_tms_buf);
+	      }
 	    }
 #endif
 	    display_service->fps_frames++;
@@ -189,7 +184,7 @@ ConditionalTimeoutRedraw(chain_t* service)
 #ifdef HAVE_SDLLIB
       if (SDL_LockYUVOverlay(info->sdloverlay) == 0) {
 	//MainStatus("Conditional display redraw");
-	convert_to_yuv_for_SDL(service->current_buffer, info->sdloverlay);
+	convert_to_yuv_for_SDL(service->current_buffer, info->sdloverlay, preferences.overlay_byte_order);
 	SDLDisplayArea(service);
 	SDL_UnlockYUVOverlay(info->sdloverlay);
 	SDL_DisplayYUVOverlay(info->sdloverlay, &info->sdlvideorect);
@@ -336,9 +331,23 @@ SDLInit(chain_t *display_service)
   //info->sdlvideo->format->BytesPerPixel=2;
 
   // Create YUV Overlay
-  info->sdloverlay = SDL_CreateYUVOverlay(display_service->current_buffer->width,
-					  display_service->current_buffer->height,
-					  SDL_YUY2_OVERLAY,info->sdlvideo);
+  switch(preferences.overlay_byte_order) {
+  case OVERLAY_BYTE_ORDER_YUYV:
+    info->sdloverlay = SDL_CreateYUVOverlay(display_service->current_buffer->width,
+					    display_service->current_buffer->height,
+					    SDL_YUY2_OVERLAY,info->sdlvideo);
+    break;
+  case OVERLAY_BYTE_ORDER_UYVY:
+    info->sdloverlay = SDL_CreateYUVOverlay(display_service->current_buffer->width,
+					    display_service->current_buffer->height,
+					    SDL_UYVY_OVERLAY,info->sdlvideo);
+    break;
+  default:
+    fprintf(stderr,"Invalid overlay byte order\n");
+    break;
+  }
+  
+
   if (info->sdloverlay==NULL) {
     MainError(SDL_GetError());
     SDL_Quit();
@@ -352,32 +361,32 @@ SDLInit(chain_t *display_service)
 
 // we should optimize this for RGB too: RGB modes could use RGB-SDL instead of YUV overlay
 void
-convert_to_yuv_for_SDL(buffer_t *buffer, SDL_Overlay *sdloverlay)
+convert_to_yuv_for_SDL(buffer_t *buffer, SDL_Overlay *sdloverlay, int overlay_byte_order)
 {
   unsigned char *dest=sdloverlay->pixels[0];
 
   switch(buffer->buffer_color_mode) {
   case COLOR_FORMAT7_MONO8:
     y2uyvy(buffer->image, dest, buffer->width, buffer->height, 
-	   sdloverlay->pitches[0]);
+	   sdloverlay->pitches[0], overlay_byte_order);
     break;
   case COLOR_FORMAT7_YUV411:
-    uyyvyy2uyvy(buffer->image,dest,buffer->width*buffer->height);
+    uyyvyy2uyvy(buffer->image,dest,buffer->width*buffer->height, overlay_byte_order);
     break;
   case COLOR_FORMAT7_YUV422:
-    yuyv2uyvy(buffer->image,dest,buffer->width*buffer->height);
+    yuyv2uyvy(buffer->image,dest,buffer->width*buffer->height, overlay_byte_order);
     break;
   case COLOR_FORMAT7_YUV444:
-    uyv2uyvy(buffer->image,dest,buffer->width*buffer->height);
+    uyv2uyvy(buffer->image,dest,buffer->width*buffer->height, overlay_byte_order);
     break;
   case COLOR_FORMAT7_RGB8:
-    rgb2uyvy(buffer->image,dest,buffer->width*buffer->height);
+    rgb2uyvy(buffer->image,dest,buffer->width*buffer->height, overlay_byte_order);
     break;
   case COLOR_FORMAT7_MONO16:
-    y162uyvy(buffer->image,dest,buffer->width*buffer->height,buffer->bpp);
+    y162uyvy(buffer->image,dest,buffer->width*buffer->height,buffer->bpp, overlay_byte_order);
     break;
   case COLOR_FORMAT7_RGB16:
-    rgb482uyvy(buffer->image,dest,buffer->width*buffer->height);
+    rgb482uyvy(buffer->image,dest,buffer->width*buffer->height, overlay_byte_order);
     break;
   }
 }
@@ -426,6 +435,224 @@ SDLDisplayArea(chain_t *display_service)
   }
 }
 
+void
+SDLDisplayPattern(chain_t *display_service)
+{
+  displaythread_info_t *info=(displaythread_info_t*)display_service->data;
+  unsigned char *pimage;
+  int sx = display_service->current_buffer->width;
+  int sy = display_service->current_buffer->height;
+  int y,u,v;
+  unsigned char block[4];
+  register int i;
+  register int j;
+
+  RGB2YUV(camera->prefs.overlay_color_r,camera->prefs.overlay_color_g,camera->prefs.overlay_color_b,y,u,v);
+
+  switch(display_service->camera->prefs.overlay_type) {
+  case OVERLAY_TYPE_REPLACE:
+    switch(preferences.overlay_byte_order) {
+    case OVERLAY_BYTE_ORDER_YUYV:
+      block[0]=y;
+      block[1]=u;
+      block[2]=y;
+      block[3]=v;
+      break;
+    case OVERLAY_BYTE_ORDER_UYVY:
+      block[0]=u;
+      block[1]=y;
+      block[2]=v;
+      block[3]=y;
+      break;
+    default:
+      fprintf(stderr,"Invalid overlay coding\n");
+      break;
+    }
+    break;
+  case OVERLAY_TYPE_RANDOM:
+    block[0]=random()/(RAND_MAX/255);
+    block[1]=random()/(RAND_MAX/255);
+    block[2]=random()/(RAND_MAX/255);
+    block[3]=random()/(RAND_MAX/255);
+    break;
+  case OVERLAY_TYPE_INVERT:
+    break;
+  default:
+    fprintf(stderr,"Invalid overlay coding\n");
+    break;
+  }
+
+  pthread_mutex_lock(&watchthread_info.mutex_area);
+  pimage=info->sdloverlay->pixels[0];
+  switch(display_service->camera->prefs.overlay_pattern) {
+  case OVERLAY_PATTERN_OFF:
+    break;
+  case OVERLAY_PATTERN_RECTANGLE:
+    if (display_service->camera->prefs.overlay_type==OVERLAY_TYPE_INVERT) {
+      j=(7*sy)/16;
+      j=j-j%4;
+      for (i=(7*sx)/16;i<=(9*sx)/16;i+=2) {
+	INVPIX(pimage, (j*sx+i)*2);
+	INVPIX(pimage, ((j-1)*sx+i)*2);
+      }
+      j=(9*sy)/16;
+      j=j-j%4;
+      for (i=(7*sx)/16;i<=(9*sx)/16;i+=2) {
+	INVPIX(pimage, (j*sx+i)*2);
+	INVPIX(pimage, ((j+1)*sx+i)*2);
+      }
+      j=(7*sx)/16;
+      j=j-j%4;
+      for (i=(7*sy)/16;i<=(9*sy)/16;i++) {
+	INVPIX(pimage, (i*sx+j)*2);
+      }
+      j=(9*sx)/16;
+      j=j-j%4;
+      for (i=(7*sy)/16;i<=(9*sy)/16;i++) {
+	INVPIX(pimage, (i*sx+j)*2);
+      }
+    }
+    else {
+      j=(7*sy)/16;
+      j=j-j%4;
+      for (i=(7*sx)/16;i<=(9*sx)/16;i+=2) {
+	REPLPIX(pimage, block, (j*sx+i)*2);
+	REPLPIX(pimage, block, ((j-1)*sx+i)*2);
+      }
+      j=(9*sy)/16;
+      j=j-j%4;
+      for (i=(7*sx)/16;i<=(9*sx)/16;i+=2) {
+	REPLPIX(pimage, block, (j*sx+i)*2);
+	REPLPIX(pimage, block, ((j+1)*sx+i)*2);
+      }
+      j=(7*sx)/16;
+      j=j-j%4;
+      for (i=(7*sy)/16;i<=(9*sy)/16;i++) {
+	REPLPIX(pimage, block, (i*sx+j)*2);
+      }
+      j=(9*sx)/16;
+      j=j-j%4;
+      for (i=(7*sy)/16;i<=(9*sy)/16;i++) {
+	REPLPIX(pimage, block, (i*sx+j)*2);
+      }
+    }
+    break;
+  case OVERLAY_PATTERN_SMALL_CROSS:
+    if (display_service->camera->prefs.overlay_type==OVERLAY_TYPE_INVERT) {
+      j=sy/2;
+      j=j-j%4;
+      for (i=(7*sx)/16;i<=(9*sx)/16;i+=2) {
+	INVPIX(pimage, (j*sx+i)*2);
+	INVPIX(pimage, ((j-1)*sx+i)*2);
+      }
+      j=sx/2;
+      j=j-j%4;
+      for (i=(7*sy)/16;i<=(9*sy)/16;i++) {
+	INVPIX(pimage, (i*sx+j)*2);
+      }
+    }
+    else {
+      j=sy/2;
+      j=j-j%4;
+      for (i=(7*sx)/16;i<=(9*sx)/16;i+=2) {
+	REPLPIX(pimage, block, (j*sx+i)*2);
+	REPLPIX(pimage, block, ((j-1)*sx+i)*2);
+      }
+      j=sx/2;
+      j=j-j%4;
+      for (i=(7*sy)/16;i<=(9*sy)/16;i++) {
+	REPLPIX(pimage, block, (i*sx+j)*2);
+      }
+    }
+    break;
+  case OVERLAY_PATTERN_LARGE_CROSS:
+    if (display_service->camera->prefs.overlay_type==OVERLAY_TYPE_INVERT) {
+      j=sy/2;
+      j=j-j%4;
+      for (i=0;i<sx;i+=2) {
+	INVPIX(pimage, (j*sx+i)*2);
+	INVPIX(pimage, ((j-1)*sx+i)*2);
+      }
+      j=sx/2;
+      j=j-j%4;
+      for (i=0;i<sy;i++) {
+	INVPIX(pimage, (i*sx+j)*2);
+      }
+    }
+    else {
+      j=sy/2;
+      j=j-j%4;
+      for (i=0;i<sx;i+=2) {
+	REPLPIX(pimage, block, (j*sx+i)*2);
+	REPLPIX(pimage, block, ((j-1)*sx+i)*2);
+      }
+      j=sx/2;
+      j=j-j%4;
+      for (i=0;i<sy;i++) {
+	REPLPIX(pimage, block, (i*sx+j)*2);
+      }
+    }
+    break;
+  case OVERLAY_PATTERN_GOLDEN_MEAN:
+    if (display_service->camera->prefs.overlay_type==OVERLAY_TYPE_INVERT) {
+      j=sy/3;
+      j=j-j%4;
+      for (i=0;i<sx;i+=2) {
+	INVPIX(pimage, (j*sx+i)*2);
+	INVPIX(pimage, ((j-1)*sx+i)*2);
+      }
+      j=2*sy/3;
+      j=j-j%4;
+      for (i=0;i<sx;i+=2) {
+	INVPIX(pimage, (j*sx+i)*2);
+	INVPIX(pimage, ((j-1)*sx+i)*2);
+      }
+      j=sx/3;
+      j=j-j%4;
+      for (i=0;i<sy;i++) {
+	INVPIX(pimage, (i*sx+j)*2);
+      }
+      j=2*sx/3;
+      j=j-j%4;
+      for (i=0;i<sy;i++) {
+	INVPIX(pimage, (i*sx+j)*2);
+      }
+    }
+    else {
+      j=sy/3;
+      j=j-j%4;
+      for (i=0;i<sx;i+=2) {
+	REPLPIX(pimage, block, (j*sx+i)*2);
+	REPLPIX(pimage, block, ((j-1)*sx+i)*2);
+      }
+      j=2*sy/3;
+      j=j-j%4;
+      for (i=0;i<sx;i+=2) {
+	REPLPIX(pimage, block, (j*sx+i)*2);
+	REPLPIX(pimage, block, ((j-1)*sx+i)*2);
+      }
+      j=sx/3;
+      j=j-j%4;
+      for (i=0;i<sy;i++) {
+	REPLPIX(pimage, block, (i*sx+j)*2);
+      }
+      j=2*sx/3;
+      j=j-j%4;
+      for (i=0;i<sy;i++) {
+	REPLPIX(pimage, block, (i*sx+j)*2);
+      }
+      
+    }
+    break;
+  case OVERLAY_PATTERN_IMAGE:
+    break;
+  default:
+    fprintf(stderr,"Wrong overlay pattern ID\n");
+    break;
+  }
+  pthread_mutex_unlock(&watchthread_info.mutex_area);
+}
+
 void
 SDLQuit(chain_t *display_service)
 {
