@@ -19,28 +19,30 @@
 #ifndef __THREAD_DISPLAY_H__
 #define __THREAD_DISPLAY_H__
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
-#ifdef HAVE_SDLLIB
-#include "SDL.h"
-#include "SDLEvent.h"
-#endif
-
-#include <math.h>
-#include "support.h"
-#include "definitions.h"
-#include "thread_base.h"
-#include "watch_thread.h"
-#include "preferences.h"
-
 typedef enum
 {
   DISPLAY_REDRAW_OFF=0,
   DISPLAY_REDRAW_ON
 } display_redraw_t;
 
+enum
+{
+  OVERLAY_PATTERN_OFF=0,
+  OVERLAY_PATTERN_RECTANGLE,
+  OVERLAY_PATTERN_SMALL_CROSS,
+  OVERLAY_PATTERN_LARGE_CROSS,
+  OVERLAY_PATTERN_GOLDEN_MEAN,
+  OVERLAY_PATTERN_IMAGE
+};
+
+enum
+{
+  OVERLAY_TYPE_REPLACE=0,
+  OVERLAY_TYPE_RANDOM,
+  OVERLAY_TYPE_INVERT,
+  OVERLAY_TYPE_AVERAGE
+};
+
 typedef struct
 {
   long int                period;
@@ -91,11 +93,14 @@ int
 SDLInit(chain_t *display_service);
 
 void
-convert_to_yuv_for_SDL(buffer_t *buffer, SDL_Overlay *sdloverlay);
+convert_to_yuv_for_SDL(buffer_t *buffer, SDL_Overlay *sdloverlay, int overlay_byte_order);
 
 void
 SDLDisplayArea(chain_t *display_service);
 
+void
+SDLDisplayPattern(chain_t *display_service);
+
 void
 SDLQuit(chain_t *display_service);
 
@@ -104,4 +109,4 @@ DisplayThreadCheckParams(chain_t *display_service);
 
 #endif
 
-#endif
+#endif // __THREAD_DISPLAY_H__
