@@ -16,12 +16,8 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "thread_ftp.h"
+#include "coriander.h"
 
-extern GtkWidget *main_window;
-extern CtxtInfo_t ctxt;
-extern camera_t* camera;
- 
 gint
 FtpStartThread(camera_t* cam)
 {
