@@ -16,41 +16,166 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "tools.h"
-#include "icons.h"
+#include "coriander.h"
   
-#define YUV2RGB(y, u, v, r, g, b)\
-  r = y + ((v*1436) >>10);\
-  g = y - ((u*352 + v*731) >> 10);\
-  b = y + ((u*1814) >> 10);\
-  r = r < 0 ? 0 : r;\
-  g = g < 0 ? 0 : g;\
-  b = b < 0 ? 0 : b;\
-  r = r > 255 ? 255 : r;\
-  g = g > 255 ? 255 : g;\
-  b = b > 255 ? 255 : b
+#ifdef HAVE_GDK_PIXBUF
+
+static char * coriander_icon_xpm[] = {
+"48 48 97 2",
+"  	c None",
+". 	c #FF3333",
+"+ 	c #47FF47",
+"@ 	c #FF5151",
+"# 	c #FF0000",
+"$ 	c #FFE974",
+"% 	c #FFE351",
+"& 	c #FFDD26",
+"* 	c #FFE248",
+"= 	c #FFE76B",
+"- 	c #00FF00",
+"; 	c #FF1414",
+"> 	c #FFDE2E",
+", 	c #FFE662",
+"' 	c #3DFF3D",
+") 	c #0AFF0A",
+"! 	c #FF0A0A",
+"~ 	c #FF6E2C",
+"{ 	c #ADEB33",
+"] 	c #FF6110",
+"^ 	c #A3E918",
+"/ 	c #7AFF7A",
+"( 	c #FF0801",
+"_ 	c #FFB91F",
+": 	c #FFDF37",
+"< 	c #FFEA7C",
+"[ 	c #FFE140",
+"} 	c #F4DE24",
+"| 	c #1EFA04",
+"1 	c #FF4F0D",
+"2 	c #FFE55A",
+"3 	c #8EEB15",
+"4 	c #14FF14",
+"5 	c #28FF28",
+"6 	c #FF4747",
+"7 	c #1EFF1E",
+"8 	c #FF3D3D",
+"9 	c #70FF70",
+"0 	c #FF7F2F",
+"a 	c #0AFD01",
+"b 	c #70F010",
+"c 	c #FF2828",
+"d 	c #FFED8E",
+"e 	c #5BFF5B",
+"f 	c #5BF20D",
+"g 	c #D6E21F",
+"h 	c #FFCB22",
+"i 	c #FF7B15",
+"j 	c #FFD424",
+"k 	c #3DF609",
+"l 	c #FF5B5B",
+"m 	c #FF1A04",
+"n 	c #FFA71C",
+"o 	c #E0E121",
+"p 	c #33F807",
+"q 	c #FFEB85",
+"r 	c #EACB22",
+"s 	c #473D0A",
+"t 	c #332C07",
+"u 	c #3D3509",
+"v 	c #7A6A12",
+"w 	c #D6B91F",
+"x 	c #A38D18",
+"y 	c #0A0801",
+"z 	c #000000",
+"A 	c #847213",
+"B 	c #C1E51C",
+"C 	c #AD9619",
+"D 	c #141103",
+"E 	c #C1A71C",
+"F 	c #66580F",
+"G 	c #E0C221",
+"H 	c #51460C",
+"I 	c #F4D424",
+"J 	c #F4DD6B",
+"K 	c #EAD262",
+"L 	c #1E1AE4",
+"M 	c #332CD3",
+"N 	c #2823DC",
+"O 	c #0000FF",
+"P 	c #5151FF",
+"Q 	c #3333FF",
+"R 	c #0A0AFF",
+"S 	c #6666FF",
+"T 	c #AD9B8E",
+"U 	c #7A6EB0",
+"V 	c #6658A8",
+"W 	c #1411ED",
+"X 	c #E0C240",
+"Y 	c #CCB051",
+"Z 	c #99847C",
+"` 	c #7A6A96",
+" .	c #473DC2",
+"..	c #2826ED",
+"+.	c #5B5BFF",
+"@.	c #4747FF",
+"#.	c #1414FF",
+"                                                                                                ",
+"                                                                                                ",
+"                                                                                                ",
+"                        .                                             +                         ",
+"                    @ # #             $ % & & & & & & * =             - -                       ",
+"                  ; # # # ;     = > & & & & & & & & & & & & & ,     ' - - )                     ",
+"                ! # # # # # ~ & & & & & & & & & & & & & & & & & & { - - - - -                   ",
+"              # # # # # # # # ] & & & & & & & & & & & & & & & & ^ - - - - - - - - /             ",
+"            ! # # # # # # # # ( _ & & : =             < [ & & } | - - - - - - - - -             ",
+"          ; # # # # # # # # # # 1 2                         $ 3 - - - - - - - - - - -           ",
+"        @ # # # # # # # # # # # #                             4 - - - - - - - - - - - 5         ",
+"        # # # # # # # # # # # # # @                         / - - - - - - - - - - - - - /       ",
+"      6 # # # # # # # # # # # # # #                         ) - - - - - - - - - - - - - 7       ",
+"          ; # # # # # # # # # # # # 8                     9 - - - - - - - - - - - - ) /         ",
+"            0 # # # # # # # # # # # #                     ) - - - - - - - - - - a b             ",
+"            & ] ( # # # # # # # # # # c     : & > % d   e - - - - - - - - - - f g &             ",
+"          = & & h 1 # # # # # # # # ( i j & & & & & & & ^ | - - - - - - - k g & & & [           ",
+"          > & & & 2   l # # # # # m n & & & & & & & & & & o p - - - - - ' q & & & & &           ",
+"          & & & &         8 # # ( n & & & r s t u v w & & & o | - - 5       & & & & & d         ",
+"        $ & & & :             c i & & & x y z z z z z A & & & B 4           2 & & & & *         ",
+"        % & & & =               j & & x z z z t y z z z v & & &               & & & : 2         ",
+"        & & & &                 & & r y z y & & & C D z z E & & =                               ",
+"        & & & &               : & & s z z & & & & & & & & & & & &                               ",
+"        & & & &               & & & t z t & & & & & & & & & & & &                               ",
+"        & & & &               > & & u z y & & & & & & & & & & & &                               ",
+"        & & & &               % & & v z z C & & & & & & & & & & &                               ",
+"        & & & &               d & & w z z D & & & w F F F G & & ,                               ",
+"        * & & & <               & & & A z z t F u y z z H & & &               & & : , q         ",
+"        = & & & [               $ & & & v z z z z z z H I & & *             , & & & & [         ",
+"          & & & &                 [ & & & E D z y s C & & & >               > & & & & <         ",
+"          & & & & $                 [ & & & & & & & & & & >                 & & & & &           ",
+"          , & & & &                   2 & & & & & & & & *                 : & & & & :           ",
+"            & & & & ,                     J & & & & K                     & & & & & q           ",
+"            * & & & &                       L M N O P                     % & & & >             ",
+"              & & & & &                   Q O O O O R                       d & & d             ",
+"              & & & & & >                 O O O O O O                           =               ",
+"              [ & & & & & >               O O O O O O S                                         ",
+"                  & & & & & & & > q     R O O O O O O O       : & %                             ",
+"                    & & & & & & & & & T O O O O O O O O U > & & & & d                           ",
+"                      : & & & & & & & V O O O O O O O O M & & & & & &                           ",
+"                        , & & & & & & W O O O O O O O O O X & & & & & ,                         ",
+"                            : & & & Y O O O O O O O O O O Z & & & > d                           ",
+"                                [ & ` O O O O O O O O O O  .& : q                               ",
+"                                    ..O O O O O O O O O O O                                     ",
+"                                    O O O O O O O O O O O O                                     ",
+"                                    O O O O O O O O O O O O +.                                  ",
+"                                  @.O O O O O O O O O O O O #.                                  ",
+"                                      S Q R O O O O O Q +.                                      "};
+
+#endif
 
-extern GtkWidget *main_window;
 extern char* trigger_mode_list[4];
 extern char* channel_num_list[16];
-extern char* phy_speed_list[4];
+extern char* phy_speed_list[7];
 extern char* phy_delay_list[4];
 extern char* power_class_list[8];
 extern char* fps_label_list[NUM_FRAMERATES];
-extern camera_t* camera;
-extern camera_t* cameras;
-extern int camera_num;
-extern CtxtInfo_t ctxt;
-extern raw1394handle_t* handles;
-extern unsigned int main_timeout_ticker;
-extern int WM_cancel_display;
-extern BusInfo_t* businfo;
-extern GtkWidget *waiting_camera_window;
-
-#ifdef HAVE_SDLLIB
-extern cursor_info_t cursor_info;
-extern watchthread_info_t watchthread_info;
-#endif
 
 void
 GetFormat7Capabilities(camera_t* cam)
@@ -101,19 +226,6 @@ GetFormat7ModeInfo(camera_t* cam, int mode_id)
       mode->unit_pos_x=0;
       mode->unit_pos_y=0;
     }
-    /*
-    // --- the following code should not be necessary with latest libdc (14/1/2004)
-    if (!((mode->unit_pos_x>0)&&(mode->unit_pos_x<mode->max_size_x)&&
-	  (mode->unit_pos_y>0)&&(mode->unit_pos_y<mode->max_size_y))) {
-      //fprintf(stderr,"UNIT_POS [%d %d] disabled, using UNIT_SIZE instead\n",info->mode[i].unit_pos_x,info->mode[i].unit_pos_y);
-      mode->unit_pos_x=mode->unit_size_x;
-      mode->unit_pos_y=mode->unit_size_y;
-    }
-    else {
-      //fprintf(stderr,"UNIT_POS [%d %d] is valid and will be used\n",info->mode[i].unit_pos_x,info->mode[i].unit_pos_y);
-    }
-    // ---
-    */
     if (dc1394_query_format7_image_position(cam->camera_info.handle,cam->camera_info.id,mode_id,&mode->pos_x,&mode->pos_y)!=DC1394_SUCCESS)
       MainError("Got a problem querying format7 image position");
     if (dc1394_query_format7_image_size(cam->camera_info.handle,cam->camera_info.id,mode_id,&mode->size_x,&mode->size_y)!=DC1394_SUCCESS)
@@ -121,11 +233,14 @@ GetFormat7ModeInfo(camera_t* cam, int mode_id)
     if (dc1394_query_format7_byte_per_packet(cam->camera_info.handle,cam->camera_info.id,mode_id,&mode->bpp)!=DC1394_SUCCESS)
       MainError("Got a problem querying format7 bytes per packet");
     if (mode->bpp==0) {
+      // sometimes a camera will not set the bpp register until a valid image size has been set after boot. If BPP is zero, we therefor
+      // try again after setting the image size to the maximum size.
       MainError("Camera reported a BPP of ZERO. Trying to set maximum size to correct this.");
       if (dc1394_set_format7_image_position(cam->camera_info.handle,cam->camera_info.id,mode_id,0,0)!=DC1394_SUCCESS)
 	MainError("Got a problem setting format7 image position");
       if (dc1394_set_format7_image_size(cam->camera_info.handle,cam->camera_info.id,mode_id,mode->max_size_x,mode->max_size_y)!=DC1394_SUCCESS)
 	MainError("Got a problem setting format7 image size");
+      // maybe we should also force a color coding here.
       if (dc1394_query_format7_byte_per_packet(cam->camera_info.handle,cam->camera_info.id,mode_id,&mode->bpp)!=DC1394_SUCCESS)
 	MainError("Got a problem querying format7 bytes per packet");
       if (mode->bpp==0) {
