@@ -16,18 +16,11 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "update_frames.h"
+#include "coriander.h"
 
-extern GtkWidget *main_window;
-extern GtkWidget *preferences_window;
-extern CtxtInfo_t ctxt;
-extern char* phy_speed_list[4];
+extern char* phy_speed_list[7];
 extern char* phy_delay_list[4];
 extern char* power_class_list[8];
-extern Prefs_t preferences; 
-extern camera_t* camera;
-extern camera_t* cameras;
-extern BusInfo_t* businfo;
 
 #ifdef HAVE_SDLLIB
 extern cursor_info_t cursor_info;
@@ -48,6 +41,8 @@ UpdatePrefsDisplayFrame(void)
 			   camera->prefs.display_redraw==DISPLAY_REDRAW_ON);
   gtk_widget_set_sensitive(lookup_widget(main_window,"label155"),
 			   camera->prefs.display_redraw==DISPLAY_REDRAW_ON);
+
+  UpdatePrefsDisplayOverlayFrame();
 }
 
 void
@@ -95,8 +90,10 @@ UpdatePrefsSaveFrame(void)
 			   camera->prefs.save_scratch==SAVE_SCRATCH_SEQUENTIAL);
   gtk_widget_set_sensitive(lookup_widget(main_window,"prefs_save_num_tag"),
 			   camera->prefs.save_scratch==SAVE_SCRATCH_SEQUENTIAL);
-  gtk_widget_set_sensitive(lookup_widget(main_window,"ram_buffer_frame"), camera->prefs.use_ram_buffer && (camera->prefs.save_scratch==SAVE_SCRATCH_VIDEO));
-  gtk_widget_set_sensitive(lookup_widget(main_window,"use_ram_buffer"), camera->prefs.save_scratch==SAVE_SCRATCH_VIDEO);
+  gtk_widget_set_sensitive(lookup_widget(main_window,"ram_buffer_frame"),
+			   camera->prefs.use_ram_buffer && (camera->prefs.save_scratch==SAVE_SCRATCH_VIDEO));
+  gtk_widget_set_sensitive(lookup_widget(main_window,"use_ram_buffer"),
+			   camera->prefs.save_scratch==SAVE_SCRATCH_VIDEO);
 
   // thread presence blanking:
   if (GetService(camera,SERVICE_SAVE)!=NULL) {
@@ -110,9 +107,6 @@ UpdatePrefsSaveFrame(void)
     else
       gtk_widget_set_sensitive(lookup_widget(main_window,"prefs_save_video"), FALSE);
   }
-      
-    
-
 }
 
 
@@ -225,7 +219,7 @@ void
 UpdateCameraStatusFrame(void)
 {
   char *temp;
-  quadlet_t sw_version;
+  int sw_version;
   quadlet_t value[3];
 
   temp=(char*)malloc(STRING_SIZE*sizeof(char));
@@ -276,11 +270,20 @@ UpdateCameraStatusFrame(void)
     sw_version=0x0;
   }
   switch (sw_version) {
-  case 0x100: sprintf(temp," 1.04 ");break;
-  case 0x101: sprintf(temp," 1.20 ");break;
-  case 0x102: sprintf(temp," 1.30 ");break;
-  case 0x114: sprintf(temp," Point Grey 114 ");break;
-  default: sprintf(temp," ?? 0x%x ",sw_version);
+  case IIDC_VERSION_1_04: sprintf(temp," 1.04 ");break;
+  case IIDC_VERSION_1_20: sprintf(temp," 1.20 ");break;
+  case IIDC_VERSION_1_30: sprintf(temp," 1.30 ");break;
+  case IIDC_VERSION_PTGREY: sprintf(temp," Pt Grey 114 ");break;
+  case IIDC_VERSION_1_31: sprintf(temp," 1.31 ");break;
+  case IIDC_VERSION_1_32: sprintf(temp," 1.32 ");break;
+  case IIDC_VERSION_1_33: sprintf(temp," 1.33 ");break;
+  case IIDC_VERSION_1_34: sprintf(temp," 1.34 ");break;
+  case IIDC_VERSION_1_35: sprintf(temp," 1.35 ");break;
+  case IIDC_VERSION_1_36: sprintf(temp," 1.36 ");break;
+  case IIDC_VERSION_1_37: sprintf(temp," 1.37 ");break;
+  case IIDC_VERSION_1_38: sprintf(temp," 1.38 ");break;
+  case IIDC_VERSION_1_39: sprintf(temp," 1.39 ");break;
+  default: sprintf(temp," ?? %d ",sw_version);
   }
   gtk_statusbar_remove((GtkStatusbar*)lookup_widget(main_window,"camera_dc_status"), ctxt.dc_ctxt, ctxt.dc_id);
   ctxt.dc_id=gtk_statusbar_push((GtkStatusbar*)lookup_widget(main_window,"camera_dc_status"), ctxt.dc_ctxt, temp);
@@ -727,3 +730,12 @@ UpdateServiceTree(void)
   }
   free(temp);
 }
+
+void
+UpdatePrefsDisplayOverlayFrame(void)
+{
+  //fprintf(stderr,"updated: %d %d\n",camera->prefs.overlay_pattern,camera->prefs.overlay_type);
+  gtk_widget_set_sensitive(lookup_widget(main_window,"overlay_type_menu"), camera->prefs.overlay_pattern!=OVERLAY_PATTERN_OFF);
+  gtk_widget_set_sensitive(lookup_widget(main_window,"overlay_color_picker"), (camera->prefs.overlay_pattern!=OVERLAY_PATTERN_OFF) && (camera->prefs.overlay_type==OVERLAY_TYPE_REPLACE));
+  gtk_widget_set_sensitive(lookup_widget(main_window,"overlay_file_entry"), (camera->prefs.overlay_pattern==OVERLAY_PATTERN_IMAGE));
+}
