@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,9 +20,15 @@
 #define __UPDATERANGES_H__
 
 void
-UpdateRange(GtkWidget* current_window, int feature);
+UpdateRange(int feature);
 
 void
 UpdateRangeValue(GtkWidget* widget, int feature);
  
-#endif
+void
+UpdateFormat7BppRange(void);
+
+void
+UpdateFormat7Ranges(void);
+
+#endif // __UPDATERANGES_H__
